import { BacktraceReportSubmission } from '../model/http/BacktraceReportSubmission';
import { BacktraceRequestHandler } from '../model/http/BacktraceRequestHandler';
import { BacktraceAttributeProvider } from '../modules/attribute/BacktraceAttributeProvider';
import { BreadcrumbsEventSubscriber, BreadcrumbsStorage } from '../modules/breadcrumbs';
import { BacktraceStackTraceConverter } from '../modules/converter';
import { BacktraceSessionProvider } from '../modules/metrics/BacktraceSessionProvider';
import { MetricsQueue } from '../modules/metrics/MetricsQueue';
import { SummedEvent } from '../modules/metrics/model/SummedEvent';
import { UniqueEvent } from '../modules/metrics/model/UniqueEvent';
import { FileSystem } from '../modules/storage';
import { CoreClientSetup } from './CoreClientSetup';
type Writeable<T> = {
    -readonly [P in keyof T]: T[P];
};
export declare abstract class BacktraceCoreClientBuilder<S extends Partial<CoreClientSetup> = Partial<CoreClientSetup>> {
    protected readonly clientSetup: Writeable<S>;
    constructor(clientSetup: Writeable<S>);
    addAttributeProvider(provider: BacktraceAttributeProvider): this;
    useBreadcrumbSubscriber(breadcrumbSubscriber: BreadcrumbsEventSubscriber): this;
    useBreadcrumbsStorage(storage: BreadcrumbsStorage): this;
    useSessionProvider(sessionProvider: BacktraceSessionProvider): this;
    useRequestHandler(handler: BacktraceRequestHandler): this;
    useStackTraceConverter(stackTraceConverter: BacktraceStackTraceConverter): this;
    useFileSystem(fileSystem: FileSystem): this;
    useReportSubmission(reportSubmission: BacktraceReportSubmission): this;
    useSummedMetricsQueue(queue: MetricsQueue<SummedEvent>): this;
    useUniqueMetricsQueue(queue: MetricsQueue<UniqueEvent>): this;
}
export {};
