"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OverwritingArray = void 0;
const OverwritingArrayIterator_1 = require("./OverwritingArrayIterator");
class OverwritingArray {
    constructor(capacity) {
        this.capacity = capacity;
        this._index = 0;
        this._size = 0;
        this._startIndex = 0;
        this._array = this.createArray();
    }
    add(value) {
        this._array[this._index] = value;
        this._index = this.incrementIndex(this._index);
        this._startIndex = this.incrementStartingIndex();
        this._size = this.incrementSize();
        return this;
    }
    clear() {
        this._array = this.createArray();
    }
    values() {
        return new OverwritingArrayIterator_1.OverwritingArrayIterator(this._array, this._startIndex, this._size);
    }
    [Symbol.iterator]() {
        return new OverwritingArrayIterator_1.OverwritingArrayIterator(this._array, this._startIndex, this._size);
    }
    incrementIndex(index) {
        return (index + 1) % this.capacity;
    }
    incrementStartingIndex() {
        if (this._size !== this.capacity) {
            return this._startIndex;
        }
        return this.incrementIndex(this._startIndex);
    }
    incrementSize() {
        return Math.min(this.capacity, this._size + 1);
    }
    createArray() {
        return new Array(this.capacity);
    }
}
exports.OverwritingArray = OverwritingArray;
//# sourceMappingURL=OverwritingArray.js.map