"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BacktraceDatabaseFileRecord = void 0;
class BacktraceDatabaseFileRecord {
    constructor(record, attachments) {
        this.attachments = attachments;
        this.data = record.data;
        this.id = record.id;
        this.count = record.count;
        this.hash = record.hash;
        this.timestamp = record.timestamp;
        // make sure the database record stored in the database directory
        // is never locked. By doing this, we want to be sure once we load
        // the record once again, the record will be available for future usage
        this.locked = false;
    }
    static fromRecord(record) {
        return new BacktraceDatabaseFileRecord(record, record.attachments.filter(BacktraceDatabaseFileRecord.isFileAttachment));
    }
    static fromJson(json, fileSystem) {
        try {
            const record = JSON.parse(json);
            const attachments = record.attachments
                ? record.attachments
                    .filter(BacktraceDatabaseFileRecord.isFileAttachment)
                    .map((n) => fileSystem.createAttachment(n.filePath, n.name))
                : [];
            return new BacktraceDatabaseFileRecord(record, attachments);
        }
        catch (_a) {
            return undefined;
        }
    }
    static isFileAttachment(attachment) {
        return 'filePath' in attachment && typeof attachment.filePath === 'string';
    }
}
exports.BacktraceDatabaseFileRecord = BacktraceDatabaseFileRecord;
//# sourceMappingURL=BacktraceDatabaseFileRecord.js.map